Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Data ¶
type Data struct {
Input struct {
Size int `json:"size"`
Type string `json:"type"`
} `json:"input"`
Output struct {
Size int `json:"size"`
Type string `json:"type"`
Width int `json:"width"`
Height int `json:"height"`
Ratio float64 `json:"ratio"`
URL string `json:"url"`
} `json:"output"`
Error string `json:"error"`
Message string `json:"message"`
}
type Option ¶
type Option func(t *tinifyClient) error
Option configures tinifyClient.
func WithAPIKey ¶
WithAPIKey returns an option that set the api key.
func WithHTTPClient ¶
func WithHTTPClient(httpClient HTTPClient) Option
WithHTTPClient returns an option that set the http client.
Click to show internal directories.
Click to hide internal directories.